SECRET_KEY = "ocyan-plugin-seo-test-key"
DEBUG = True
USE_TZ = True
ROOT_URLCONF = "ocyan.plugin.seo.test_urls"
STATIC_URL = "/static/"
MEDIA_URL = "/media/"
MEDIA_ROOT = "/tmp/ocyan-plugin-seo-media"
INSTALLED_APPS = []
MIDDLEWARE = []
DATABASES = {"default": {"ENGINE": "django.db.backends.sqlite3", "NAME": ":memory:"}}
TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {"context_processors": []},
    }
]
