from pathlib import Path

from setuptools import find_packages, setup

BASE_DIR = Path(__file__).parent
README = (BASE_DIR / "README.rst").read_text(encoding="utf-8")

install_requires = [
    "Django>=5,<6",
    "ocyan.core",
    "seo-ville-slugger",
]


setup(
    name="ocyan.plugin.seo",
    version="0.2.1",
    url="https://git.mandelblog.com/mandel-plugins/ocyan.plugin.seo",
    author="Mandel",
    author_email="info@mandelblog.com",
    description="SEO-friendly media storage settings for MandelBlogStack Django sites",
    long_description=README,
    long_description_content_type="text/x-rst",
    license="LicenseRef-Proprietary",
    license_files=("COPYRIGHT",),
    packages=find_packages(),
    include_package_data=True,
    python_requires=">=3.10",
    install_requires=install_requires,
    extras_require={"test": ["configtype"]},
    classifiers=[
        "Framework :: Ocyan",
        "Environment :: Plugins",
    ],
)
